%define up_name	DisplayCAL

Name:		displaycal
Version:	3.9.16
Release:	%mkrel 1
Summary:	A graphical user interface for the Argyll CMS display calibration utilities
Group: 		Graphics/Utilities
License:	GPLv3
URL:		https://github.com/eoyilmaz/displaycal-py3
Source0:	https://github.com/eoyilmaz/displaycal-py3/releases/download/%{version}/DisplayCAL-%{version}.tar.gz
Patch0:		displaycal-3.9.3-udev-dir.patch
Patch1:		displaycal-skip-update-check.patch
Patch2:		displaycal-3.9.14-fix-autostart-location.patch
Patch3:		displaycal-3.9.16-revert-license-field-change.patch
BuildArch:	noarch
BuildRequires:	pyproject-rpm-macros
BuildRequires:	python3dist(setuptools-scm)
BuildRequires:	python3dist(setuptools-scm[toml])
BuildRequires:	python3dist(wheel)
BuildRequires:	python3dist(pip)
BuildRequires:	python3dist(wxpython)
BuildRequires:	pkgconfig(xxf86vm)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xrandr)
BuildRequires:	pkgconfig(python3)
BuildRequires:	xdg-user-dirs
BuildRequires:	locales-fr

Requires:	argyllcms
# workaround for crash with pyglet as sound backend
Requires:	sdl2_mixer

Requires:	python3dist(setuptools)
Requires:	python3dist(pygobject)
Requires:	python3dist(numpy)
Requires:	python3dist(wxpython)
Requires:	python3dist(send2trash)
Requires:	python3dist(distro)

Provides:	%{up_name} = %{version}-%{release}
Provides:	dispcalGUI = %{version}-%{release}

%description
A graphical user interface for the Argyll CMS display calibration utilities.

%files
%docdir %{_docdir}/%{up_name}-%{version}/
%doc %{_docdir}/%{up_name}-%{version}/*
%{_sysconfdir}/xdg/autostart/z-displaycal-apply-profiles.desktop
%{_bindir}/*
%{_datadir}/%{up_name}/
%{_iconsdir}/hicolor/*/apps/%{name}*.png
%{_datadir}/applications/*.desktop
%{_metainfodir}/net.displaycal.%{up_name}.appdata.xml
%{_mandir}/man1/*

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}

# Delete existing egg
rm -rf DisplayCAL.egg-info
# Delete PKG-INFO that causes inadvertent Python version restrictions
rm PKG-INFO

# hack to force creating dist/net.displaycal... (missed due pyproject)
sed -i -e 's|create_appdata = |create_appdata = True or |' setup.py

# drop prebuilt modules
find . -name '*.so' -print -delete

# fix paths
%ifarch %arm32 %ix86
ln -s ./lib64 DisplayCAL/lib32
sed -i -e 's/DisplayCAL\.lib64/DisplayCAL\.lib32/g' DisplayCAL/RealDisplaySizeMM.py
%endif

%generate_buildrequires
%pyproject_buildrequires


%build
export LC_ALL=fr_FR.UTF-8
export CFLAGS="%{optflags} -Wno-incompatible-pointer-types"
%pyproject_wheel

%install
export LC_ALL=fr_FR.UTF-8
%pyproject_install
%pyproject_save_files %{name}
mkdir -p %{buildroot}%{_sysconfdir}/xdg/autostart/
mv %{buildroot}%{_datadir}/DisplayCAL/z-displaycal-apply-profiles.desktop %{buildroot}%{_sysconfdir}/xdg/autostart/

# Drop files that aren't supposed to be shipped
rm -rfv %{buildroot}%{python3_sitelib}/{misc,tests,util}
rm -rfv %{buildroot}%{_datadir}/doc-base


%changelog
* Mon May 05 2025 daviddavid <daviddavid> 3.9.16-1.mga10
+ Revision: 2181213
- new version: 3.9.16

* Mon Mar 03 2025 daviddavid <daviddavid> 3.9.14-2.mga10
+ Revision: 2159293
- rebuild for python 3.13

* Mon Jan 06 2025 daviddavid <daviddavid> 3.9.14-1.mga10
+ Revision: 2135794
- new version: 3.9.14

* Thu Apr 04 2024 daviddavid <daviddavid> 3.9.12-1.mga10
+ Revision: 2054356
- new version: 3.9.12

* Tue Jan 16 2024 papoteur <papoteur> 3.9.11-3.mga10
+ Revision: 2031653
- workaround for crash with pyglet as sound backend, pulling sdl2_mixer which has precedence (mga#32697)

* Sun Dec 31 2023 daviddavid <daviddavid> 3.9.11-2.mga10
+ Revision: 2024873
- add py3.12 support

* Tue Dec 19 2023 daviddavid <daviddavid> 3.9.11-1.mga10
+ Revision: 2019816
- new version: 3.9.11

* Tue Dec 19 2023 papoteur <papoteur> 3.9.10-3.mga10
+ Revision: 2019485
- Mass Rebuild - Python 3.12
+ daviddavid <daviddavid>
- rebuild for py3.12

* Thu Dec 01 2022 daviddavid <daviddavid> 3.9.10-1.mga9
+ Revision: 1913674
- new version: 3.9.10
- rediff skip-update-check patch

* Fri Sep 30 2022 papoteur <papoteur> 3.9.8-1.mga9
+ Revision: 1893487
- fix installation location of autostart file
- new version: 3.9.8

* Sun May 15 2022 papoteur <papoteur> 3.9.3-1.mga9
+ Revision: 1858237
- new 3.9.3
- restore displaycal now ported to Python 3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Mon Aug 19 2019 daviddavid <daviddavid> 3.8.5.0-1.mga8
+ Revision: 1429917
- new version: 3.8.5.0

* Mon Jul 08 2019 daviddavid <daviddavid> 3.8.3.0-1.mga8
+ Revision: 1419467
- new version: 3.8.3.0

* Fri Apr 05 2019 daviddavid <daviddavid> 3.7.2.0-1.mga7
+ Revision: 1385912
- new version: 3.7.2.0

* Mon Jan 28 2019 daviddavid <daviddavid> 3.7.1.4-1.mga7
+ Revision: 1361558
- new version: 3.7.1.4

* Tue Dec 25 2018 daviddavid <daviddavid> 3.7.1.3-1.mga7
+ Revision: 1344960
- new version: 3.7.1.3

* Fri Nov 30 2018 daviddavid <daviddavid> 3.7.1.2-1.mga7
+ Revision: 1336811
- new version: 3.7.1.2

* Sun Nov 18 2018 daviddavid <daviddavid> 3.7.1.1-1.mga7
+ Revision: 1330755
- new version: 3.7.1.1

* Sun Oct 21 2018 daviddavid <daviddavid> 3.7.0.0-1.mga7
+ Revision: 1323222
- new version: 3.7.0.0
- switch to 55-Argyll.rules to support new udev (mga#23733)

* Sat Sep 22 2018 daviddavid <daviddavid> 3.6.2.0-1.mga7
+ Revision: 1295897
- new version: 3.6.2.0

* Sat Aug 18 2018 daviddavid <daviddavid> 3.6.1.1-1.mga7
+ Revision: 1252514
- new version: 3.6.1.1

* Mon Apr 30 2018 daviddavid <daviddavid> 3.5.3.0-1.mga7
+ Revision: 1223902
- new version: 3.5.3.0

* Sat Apr 07 2018 daviddavid <daviddavid> 3.5.2.0-1.mga7
+ Revision: 1215879
- new version: 3.5.2.0

* Fri Mar 23 2018 daviddavid <daviddavid> 3.5.1.0-1.mga7
+ Revision: 1211431
- new version: 3.5.1.0
- rename and rediff udev-dir patch

* Mon Feb 26 2018 daviddavid <daviddavid> 3.5.0.0-1.mga7
+ Revision: 1205245
- new version: 3.5.0.0

* Thu Jan 04 2018 daviddavid <daviddavid> 3.4.0.0-1.mga7
+ Revision: 1190081
- new version: 3.4.0.0

* Thu Nov 09 2017 daviddavid <daviddavid> 3.3.5.0-1.mga7
+ Revision: 1176692
- new version: 3.3.5.0

* Sat Sep 23 2017 daviddavid <daviddavid> 3.3.4.1-1.mga7
+ Revision: 1157787
- new version: 3.3.4.1

* Sat Sep 02 2017 daviddavid <daviddavid> 3.3.3.0-1.mga7
+ Revision: 1150723
- new version: 3.3.3.0

* Sun Jul 02 2017 daviddavid <daviddavid> 3.3.2.0-1.mga6
+ Revision: 1108913
- new version: 3.3.2.0

* Sun Jan 15 2017 daviddavid <daviddavid> 3.2.3.0-1.mga6
+ Revision: 1081884
- new version: 3.2.3.0

* Sun Dec 11 2016 daviddavid <daviddavid> 3.2.1.0-1.mga6
+ Revision: 1074203
- new version: 3.2.1.0

* Sun Oct 30 2016 daviddavid <daviddavid> 3.1.7.3-1.mga6
+ Revision: 1064156
- new version: 3.1.7.3

* Fri Oct 14 2016 daviddavid <daviddavid> 3.1.7.0-1.mga6
+ Revision: 1060737
- new version: 3.1.7.0

* Sun Aug 28 2016 daviddavid <daviddavid> 3.1.6.0-1.mga6
+ Revision: 1049349
- new version: 3.1.6.0

* Sat Aug 20 2016 daviddavid <daviddavid> 3.1.5.0-1.mga6
+ Revision: 1047143
- new version: 3.1.5.0

* Sun Jul 24 2016 daviddavid <daviddavid> 3.1.4.0-1.mga6
+ Revision: 1043512
- new version: 3.1.4.0

* Tue May 10 2016 daviddavid <daviddavid> 3.1.3.1-1.mga6
+ Revision: 1012317
- new version: 3.1.3.1

* Mon Feb 22 2016 daviddavid <daviddavid> 3.1.0.0-1.mga6
+ Revision: 976005
- new version: 3.1.0.0 (fixes mga#17803)
- new upstream URL and Source URL
- rename and rediff udev-dir patch
- use new python macros
- requires python-numpy
- obsoletes/provides old upstream name on dispcalGUI
- update files list
- move to new upstream name on displaycal

* Fri Feb 05 2016 umeabot <umeabot> 1.2.7.0-9.mga6
+ Revision: 938821
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.2.7.0-8.mga5
+ Revision: 744682
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.7.0-7.mga5
+ Revision: 726130
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.7.0-6.mga5
+ Revision: 678756
- Mageia 5 Mass Rebuild
+ ovitters <ovitters>
- add gobject-introspection BR for typelib auto BR

* Sat May 31 2014 pterjan <pterjan> 1.2.7.0-5.mga5
+ Revision: 628160
- Rebuild for new Python

* Sat Nov 02 2013 fwang <fwang> 1.2.7.0-4.mga4
+ Revision: 548862
- add requires on python-gi

* Tue Oct 22 2013 umeabot <umeabot> 1.2.7.0-3.mga4
+ Revision: 542551
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 1.2.7.0-2.mga4
+ Revision: 497727
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Jul 31 2013 fwang <fwang> 1.2.7.0-1.mga4
+ Revision: 461407
- update file list
- new version 1.2.7.0

* Sun Feb 10 2013 neoclust <neoclust> 0.8.9.3-1.mga3
+ Revision: 397779
- imported package dispcalGUI

